@@ -35,7 +35,8 @@
 
 class KProcess;
 class KPtyProcess;
-class QTemporaryDir;
+
+class QDir;
 
 namespace Kerfuffle
 {
@@ -180,6 +181,11 @@ enum CliInterfaceParameters {
      * index 4 - Cancel operation
      */
     FileExistsInput,
+    /**
+      * QStringList
+      * Regexp patterns capturing disk is full error messages.
+      */
+    DiskFullPatterns,
 
     ///////////////[ DELETE ]/////////////
 
@@ -305,10 +311,67 @@ public:
      */
     void setListEmptyLines(bool emptyLines);
 
-private:
+    /**
+     * Move all files from @p tmpDir to @p destDir, preserving paths if @p preservePaths is true.
+     * @return Whether the operation has been successfull.
+     */
+    bool moveToDestination(const QDir &tempDir, const QDir &destDir, bool preservePaths);
+
+    QStringList substituteCopyVariables(const QStringList &extractArgs, const QVariantList &files, bool preservePaths, const QString &password, const QString &rootNode);
+
+    /**
+     * @return The preserve path switch, according to the @p preservePaths extraction option.
+     */
+    QString preservePathSwitch(bool preservePaths) const;
+
+    /**
+     * @return The password switch with the given @p password.
+     */
+    QStringList passwordSwitch(const QString& password) const;
+
+    /**
+     * @return The root node switch with the given @p rootNode.
+     */
+    QStringList rootNodeSwitch(const QString& rootNode) const;
+
+    /**
+     * @return The list of selected files to extract.
+     */
+    QStringList copyFilesList(const QVariantList& files) const;
+
+protected:
+
+    virtual void handleLine(const QString& line);
+    virtual void cacheParameterList();
     void substituteListVariables(QStringList& params);
 
-    void cacheParameterList();
+    /**
+     * Run @p programName with the given @p arguments.
+     * The method waits until @p programName is finished to exit.
+     *
+     * @param programName The program that will be run (not the whole path).
+     * @param arguments A list of arguments that will be passed to the program.
+     *
+     * @return @c true if the program was found and the process ran correctly,
+     *         @c false otherwise.
+     */
+    bool runProcess(const QStringList& programNames, const QStringList& arguments);
+
+    void failOperation();
+
+    /**
+     * Ask the password *before* running any process.
+     * @return True if the user supplies a password, false otherwise (in which case finished() is emitted).
+     */
+    bool passwordQuery();
+
+    ParameterList m_param;
+    int m_exitCode;
+
+protected slots:
+    virtual void readStdout(bool handleAll = false);
+
+private:
 
     /**
      * Checks whether a line of the program's output is a password prompt.
@@ -326,21 +389,6 @@ private:
 
     bool handleFileExistsMessage(const QString& filename);
     bool checkForErrorMessage(const QString& line, int parameterIndex);
-    void handleLine(const QString& line);
-
-    void failOperation();
-
-    /**
-     * Run @p programName with the given @p arguments.
-     * The method waits until @p programName is finished to exit.
-     *
-     * @param programName The program that will be run (not the whole path).
-     * @param arguments A list of arguments that will be passed to the program.
-     *
-     * @return @c true if the program was found and the process ran correctly,
-     *         @c false otherwise.
-     */
-    bool runProcess(const QStringList& programNames, const QStringList& arguments);
 
     /**
      * Performs any additional escaping and processing on @p fileName
@@ -358,7 +406,12 @@ private:
      */
     void writeToProcess(const QByteArray& data);
 
-    bool moveToFinalDest(const QVariantList &files, const QString &finalDest, const QTemporaryDir &tmpDir);
+    bool moveDroppedFilesToDest(const QVariantList &files, const QString &finalDest);
+
+    /**
+     * @return Whether @p dir is an empty directory.
+     */
+    bool isEmptyDir(const QDir &dir);
 
     QByteArray m_stdOutData;
     QRegularExpression m_passwordPromptPattern;
@@ -370,14 +423,12 @@ private:
     KPtyProcess *m_process;
 #endif
 
-    ParameterList m_param;
     QVariantList m_removedFiles;
     bool m_listEmptyLines;
     bool m_abortingOperation;
     QString m_storedFileName;
 
 private slots:
-    void readStdout(bool handleAll = false);
     void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
 };
 }
