@@ -33,7 +33,7 @@
 
 using namespace Kerfuffle;
 
-K_PLUGIN_FACTORY( CliPluginFactory, registerPlugin< CliPlugin >(); )
+K_PLUGIN_FACTORY_WITH_JSON(CliPluginFactory, "kerfuffle_cli7z.json", registerPlugin<CliPlugin>();)
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList & args)
         : CliInterface(parent, args)
@@ -60,9 +60,7 @@ ParameterList CliPlugin::parameterList() const
 
     if (p.isEmpty()) {
         //p[CaptureProgress] = true;
-        p[ListProgram] = p[ExtractProgram] = p[DeleteProgram] = p[AddProgram] = QStringList() << QStringLiteral("7z")
-                                                                                              << QStringLiteral("7za")
-                                                                                              << QStringLiteral("7zr");
+        p[ListProgram] = p[ExtractProgram] = p[DeleteProgram] = p[AddProgram] = QStringList() << QStringLiteral("7z");
         p[ListArgs] = QStringList() << QStringLiteral("l")
                                     << QStringLiteral("-slt")
                                     << QStringLiteral("$PasswordSwitch")
@@ -95,10 +93,11 @@ ParameterList CliPlugin::parameterList() const
                                            << QStringLiteral("A")  //overwrite all
                                            << QStringLiteral("S")  //autoskip
                                            << QStringLiteral("Q"); //cancel
-
         p[PasswordPromptPattern] = QStringLiteral("Enter password \\(will not be echoed\\)");
+        p[ExtractionFailedPatterns] = QStringList() << QStringLiteral("ERROR: E_FAIL");
         p[CorruptArchivePatterns] = QStringList() << QStringLiteral("Unexpected end of archive")
                                                   << QStringLiteral("Headers Error");
+        p[DiskFullPatterns] = QStringList() << QStringLiteral("No space left on device");
     }
 
     return p;
