@@ -106,6 +106,7 @@ bool ReadWriteLibarchivePlugin::addFiles(const QStringList& files, const Compres
     archive_write_set_format_pax_restricted(arch_writer.data());
 
     int ret;
+    bool isLrzip = false;
     if (creatingNewFile) {
         if (filename().right(2).toUpper() == QLatin1String("GZ")) {
             qCDebug(ARK) << "Detected gzip compression for new file";
@@ -131,6 +132,7 @@ bool ReadWriteLibarchivePlugin::addFiles(const QStringList& files, const Compres
         } else if (filename().right(3).toUpper() == QLatin1String("LRZ")) {
             qCDebug(ARK) << "Detected lrzip compression for new file";
             ret = archive_write_add_filter_lrzip(arch_writer.data());
+            isLrzip = true;
         } else if (filename().right(3).toUpper() == QLatin1String("TAR")) {
             qCDebug(ARK) << "Detected no compression for new file (pure tar)";
             ret = archive_write_add_filter_none(arch_writer.data());
@@ -139,7 +141,9 @@ bool ReadWriteLibarchivePlugin::addFiles(const QStringList& files, const Compres
             ret = archive_write_add_filter_gzip(arch_writer.data());
         }
 
-        if (ret != ARCHIVE_OK) {
+        // Libarchive emits a warning for lrzip due to using external executable.
+        if ((isLrzip && ret != ARCHIVE_WARN) ||
+            (!isLrzip && ret != ARCHIVE_OK)) {
             emit error(xi18nc("@info", "Setting the compression method failed with the following error:<nl/><message>%1</message>",
                               QLatin1String(archive_error_string(arch_writer.data()))));
             return false;
@@ -169,6 +173,7 @@ bool ReadWriteLibarchivePlugin::addFiles(const QStringList& files, const Compres
             break;
         case ARCHIVE_FILTER_LRZIP:
             ret = archive_write_add_filter_lrzip(arch_writer.data());
+            isLrzip = true;
             break;
         case ARCHIVE_FILTER_NONE:
             ret = archive_write_add_filter_none(arch_writer.data());
@@ -179,7 +184,9 @@ bool ReadWriteLibarchivePlugin::addFiles(const QStringList& files, const Compres
             return false;
         }
 
-        if (ret != ARCHIVE_OK) {
+        // Libarchive emits a warning for lrzip due to using external executable.
+        if ((isLrzip && ret != ARCHIVE_WARN) ||
+            (!isLrzip && ret != ARCHIVE_OK)) {
             emit error(xi18nc("@info", "Setting the compression method failed with the following error:<nl/><message>%1</message>",
                               QLatin1String(archive_error_string(arch_writer.data()))));
             return false;
